/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                          **** ESPAOL *****
/*
/*                     Ciclo escolar evaluado: 2007 - 2008
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE ESPAOL
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2008_Alum_Esp.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2008_Alum_Esp.txt
/*         as como el archivo Excale09_2008_Alum_Esp.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2008_Alum_Esp.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2008_Alum_Esp.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 16 DE MARZO DEL 2010
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale09_2008_Alum_Esp.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $mageb05f   "R"       ="Escuela rural"
                       "UA"      ="Escuela urbana de alta marginacin"
                       "UB"      ="Escuela urbana de baja marginacin"
                       "NA"      ="No aplica";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="14 aos o menos"
                       2         ="15 aos"
                       3         ="16 aos"
                       4         ="17 aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE ea1_h18F    0         ="Fallo"
                       1         ="Acierto (pregunta dicotmica)/Acierto parcial (Pregunta politmica)"
                       2         ="Acierto total (pregunta dicotmica)"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Reactivo no administrado por error de impresin"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale09_2008_Alum_Esp;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       mageb05            $2
       estrato            $7
       entest             $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       sea_01             3
       sea_02             3
       sea_03             3
       sea_04             3
       sea_05             3
       sea_06             3
       sea_07             3
       sea_08             3
       sea_09             3
       sea_10             3
       sea_11             3
       sea_12             3
       sea_13             3
       sea_14             3
       sea_15             3
       sea_16             3
       sea_17             3
       sea_18             3
       seb_01             3
       seb_02             3
       seb_03             3
       seb_04             3
       seb_05             3
       seb_06             3
       seb_07             3
       seb_08             3
       seb_09             3
       seb_10             3
       seb_11             3
       seb_12             3
       seb_13             3
       seb_14             3
       seb_15             3
       seb_16             3
       seb_17             3
       seb_18             3
       sec_01             3
       sec_02             3
       sec_03             3
       sec_04             3
       sec_05             3
       sec_06             3
       sec_07             3
       sec_08             3
       sec_09             3
       sec_10             3
       sec_11             3
       sec_12             3
       sec_13             3
       sec_14             3
       sec_15             3
       sec_16             3
       sec_17             3
       sec_18             3
       sec_19             3
       sed_01             3
       sed_02             3
       sed_03             3
       sed_04             3
       sed_05             3
       sed_06             3
       sed_07             3
       sed_08             3
       sed_09             3
       sed_10             3
       sed_11             3
       sed_12             3
       sed_13             3
       sed_14             3
       sed_15             3
       sed_16             3
       sed_17             3
       sed_18             3
       see_01             3
       see_02             3
       see_03             3
       see_04             3
       see_05             3
       see_06             3
       see_07             3
       see_08             3
       see_09             3
       see_10             3
       see_11             3
       see_12             3
       see_13             3
       see_14             3
       see_15             3
       see_16             3
       see_17             3
       see_18             3
       sef_01             3
       sef_02             3
       sef_03             3
       sef_04             3
       sef_05             3
       sef_06             3
       sef_07             3
       sef_08             3
       sef_09             3
       sef_10             3
       sef_11             3
       sef_12             3
       sef_13             3
       sef_14             3
       sef_15             3
       sef_16             3
       sef_17             3
       sef_18             3
       seg_01             3
       seg_02             3
       seg_03             3
       seg_04             3
       seg_05             3
       seg_06             3
       seg_07             3
       seg_08             3
       seg_09             3
       seg_10             3
       seg_11             3
       seg_12             3
       seg_13             3
       seg_14             3
       seg_15             3
       seg_16             3
       seg_17             3
       seg_18             3
       seh_01             3
       seh_02             3
       seh_03             3
       seh_04             3
       seh_05             3
       seh_06             3
       seh_07             3
       seh_08             3
       seh_09             3
       seh_10             3
       seh_11             3
       seh_12             3
       seh_13             3
       seh_14             3
       seh_15             3
       seh_16             3
       seh_17             3
       seh_18             3
       pv1esp             8
       pv2esp             8
       pv3esp             8
       pv4esp             8
       pv5esp             8
       espnvl1            3
       espnvl2            3
       espnvl3            3
       espnvl4            3
       espnvl5            3
       espnvlb1           3
       espnvlb2           3
       espnvlb3           3
       espnvlb4           3
       espnvlb5           3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
 ;

INFILE alum MISSOVER LINESIZE = 1179;
   INPUT
       nacional           1 - 1
       escuela            2 - 5
       id_ent             6 - 7
       nom_ent            8 - 26
       id_mod            27 - 27
       mod               28 - 31
       mageb05           32 - 33
       estrato           34 - 40
       entest            41 - 46
       alumno            47 - 52
       id_instr          53 - 68
       sexo              69 - 69
       edad              70 - 80
       edadc             81 - 81
       edadn             82 - 82
       edad_ac           83 - 84
       mes_nac           85 - 86
       w_alu             87 - 97
       docente           98 - 102
       sea_01           103 - 103
       sea_02           104 - 104
       sea_03           105 - 105
       sea_04           106 - 106
       sea_05           107 - 107
       sea_06           108 - 108
       sea_07           109 - 109
       sea_08           110 - 110
       sea_09           111 - 111
       sea_10           112 - 112
       sea_11           113 - 113
       sea_12           114 - 114
       sea_13           115 - 115
       sea_14           116 - 116
       sea_15           117 - 117
       sea_16           118 - 118
       sea_17           119 - 119
       sea_18           120 - 120
       seb_01           121 - 121
       seb_02           122 - 122
       seb_03           123 - 123
       seb_04           124 - 124
       seb_05           125 - 125
       seb_06           126 - 126
       seb_07           127 - 127
       seb_08           128 - 128
       seb_09           129 - 129
       seb_10           130 - 130
       seb_11           131 - 131
       seb_12           132 - 132
       seb_13           133 - 133
       seb_14           134 - 134
       seb_15           135 - 135
       seb_16           136 - 136
       seb_17           137 - 137
       seb_18           138 - 138
       sec_01           139 - 139
       sec_02           140 - 140
       sec_03           141 - 141
       sec_04           142 - 142
       sec_05           143 - 143
       sec_06           144 - 144
       sec_07           145 - 145
       sec_08           146 - 146
       sec_09           147 - 147
       sec_10           148 - 148
       sec_11           149 - 149
       sec_12           150 - 150
       sec_13           151 - 151
       sec_14           152 - 152
       sec_15           153 - 153
       sec_16           154 - 154
       sec_17           155 - 155
       sec_18           156 - 156
       sec_19           157 - 157
       sed_01           158 - 158
       sed_02           159 - 159
       sed_03           160 - 160
       sed_04           161 - 161
       sed_05           162 - 162
       sed_06           163 - 163
       sed_07           164 - 164
       sed_08           165 - 165
       sed_09           166 - 166
       sed_10           167 - 167
       sed_11           168 - 168
       sed_12           169 - 169
       sed_13           170 - 170
       sed_14           171 - 171
       sed_15           172 - 172
       sed_16           173 - 173
       sed_17           174 - 174
       sed_18           175 - 175
       see_01           176 - 176
       see_02           177 - 177
       see_03           178 - 178
       see_04           179 - 179
       see_05           180 - 180
       see_06           181 - 181
       see_07           182 - 182
       see_08           183 - 183
       see_09           184 - 184
       see_10           185 - 185
       see_11           186 - 186
       see_12           187 - 187
       see_13           188 - 188
       see_14           189 - 189
       see_15           190 - 190
       see_16           191 - 191
       see_17           192 - 192
       see_18           193 - 193
       sef_01           194 - 194
       sef_02           195 - 195
       sef_03           196 - 196
       sef_04           197 - 197
       sef_05           198 - 198
       sef_06           199 - 199
       sef_07           200 - 200
       sef_08           201 - 201
       sef_09           202 - 202
       sef_10           203 - 203
       sef_11           204 - 204
       sef_12           205 - 205
       sef_13           206 - 206
       sef_14           207 - 207
       sef_15           208 - 208
       sef_16           209 - 209
       sef_17           210 - 210
       sef_18           211 - 211
       seg_01           212 - 212
       seg_02           213 - 213
       seg_03           214 - 214
       seg_04           215 - 215
       seg_05           216 - 216
       seg_06           217 - 217
       seg_07           218 - 218
       seg_08           219 - 219
       seg_09           220 - 220
       seg_10           221 - 221
       seg_11           222 - 222
       seg_12           223 - 223
       seg_13           224 - 224
       seg_14           225 - 225
       seg_15           226 - 226
       seg_16           227 - 227
       seg_17           228 - 228
       seg_18           229 - 229
       seh_01           230 - 230
       seh_02           231 - 231
       seh_03           232 - 232
       seh_04           233 - 233
       seh_05           234 - 234
       seh_06           235 - 235
       seh_07           236 - 236
       seh_08           237 - 237
       seh_09           238 - 238
       seh_10           239 - 239
       seh_11           240 - 240
       seh_12           241 - 241
       seh_13           242 - 242
       seh_14           243 - 243
       seh_15           244 - 244
       seh_16           245 - 245
       seh_17           246 - 246
       seh_18           247 - 247
       pv1esp           248 - 255
       pv2esp           256 - 263
       pv3esp           264 - 271
       pv4esp           272 - 279
       pv5esp           280 - 287
       espnvl1          288 - 288
       espnvl2          289 - 289
       espnvl3          290 - 290
       espnvl4          291 - 291
       espnvl5          292 - 292
       espnvlb1         293 - 293
       espnvlb2         294 - 294
       espnvlb3         295 - 295
       espnvlb4         296 - 296
       espnvlb5         297 - 297
       wvarstrr         298 - 299
       w_fstr1          300 - 310
       w_fstr2          311 - 321
       w_fstr3          322 - 332
       w_fstr4          333 - 343
       w_fstr5          344 - 354
       w_fstr6          355 - 365
       w_fstr7          366 - 376
       w_fstr8          377 - 387
       w_fstr9          388 - 398
       w_fstr10         399 - 409
       w_fstr11         410 - 420
       w_fstr12         421 - 431
       w_fstr13         432 - 442
       w_fstr14         443 - 453
       w_fstr15         454 - 464
       w_fstr16         465 - 475
       w_fstr17         476 - 486
       w_fstr18         487 - 497
       w_fstr19         498 - 508
       w_fstr20         509 - 519
       w_fstr21         520 - 530
       w_fstr22         531 - 541
       w_fstr23         542 - 552
       w_fstr24         553 - 563
       w_fstr25         564 - 574
       w_fstr26         575 - 585
       w_fstr27         586 - 596
       w_fstr28         597 - 607
       w_fstr29         608 - 618
       w_fstr30         619 - 629
       w_fstr31         630 - 640
       w_fstr32         641 - 651
       w_fstr33         652 - 662
       w_fstr34         663 - 673
       w_fstr35         674 - 684
       w_fstr36         685 - 695
       w_fstr37         696 - 706
       w_fstr38         707 - 717
       w_fstr39         718 - 728
       w_fstr40         729 - 739
       w_fstr41         740 - 750
       w_fstr42         751 - 761
       w_fstr43         762 - 772
       w_fstr44         773 - 783
       w_fstr45         784 - 794
       w_fstr46         795 - 805
       w_fstr47         806 - 816
       w_fstr48         817 - 827
       w_fstr49         828 - 838
       w_fstr50         839 - 849
       w_fstr51         850 - 860
       w_fstr52         861 - 871
       w_fstr53         872 - 882
       w_fstr54         883 - 893
       w_fstr55         894 - 904
       w_fstr56         905 - 915
       w_fstr57         916 - 926
       w_fstr58         927 - 937
       w_fstr59         938 - 948
       w_fstr60         949 - 959
       w_fstr61         960 - 970
       w_fstr62         971 - 981
       w_fstr63         982 - 992
       w_fstr64         993 - 1003
       w_fstr65        1004 - 1014
       w_fstr66        1015 - 1025
       w_fstr67        1026 - 1036
       w_fstr68        1037 - 1047
       w_fstr69        1048 - 1058
       w_fstr70        1059 - 1069
       w_fstr71        1070 - 1080
       w_fstr72        1081 - 1091
       w_fstr73        1092 - 1102
       w_fstr74        1103 - 1113
       w_fstr75        1114 - 1124
       w_fstr76        1125 - 1135
       w_fstr77        1136 - 1146
       w_fstr78        1147 - 1157
       w_fstr79        1158 - 1168
       w_fstr80        1169 - 1179
;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       mageb05     = "ndice de marginacin urbana 2005"
       estrato     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       alumno      = "Identificador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2008, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2008, codificada (al momento de la aplicacin)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       sea_01      = "Identificar oracin temtica: artculo opinin"
       sea_02      = "Identificar propsito: artculo de opinin"
       sea_03      = "Reconocer la opinin del autor: artculo de opinin"
       sea_04      = "Seleccionar argumentos que apoyan la opinin del autor"
       sea_05      = "Identificar la conclusin del autor: artculo de opinin"
       sea_06      = "Identificar si un artculo de opinin est prejuiciado o no"
       sea_07      = "Interpretar significado de expresiones denotativas"
       sea_08      = "Interpretar sentido de acotaciones: teatro"
       sea_09      = "Identificar caractersticas de un personaje en obra de teatro"
       sea_10      = "Identificar tema central: teatro"
       sea_11      = "Interpretar el sentido de una oracin por su puntuacin"
       sea_12      = "Identificar la secuencia argumentativa: texto cientfico"
       sea_13      = "Seleccionar fuentes de informacin para desarrollar un tema"
       sea_14      = "Identificar el  uso correcto  del guin largo"
       sea_15      = "Identificar el uso correcto de los puntos suspensivos"
       sea_16      = "Identificar el pronombre que sustituye al objeto directo"
       sea_17      = "Identificar el referente que sustituye al objeto indirecto"
       sea_18      = "Reconocer el uso correcto de palabras homfonas"
       seb_01      = "Identificar crnica por sus caractersticas"
       seb_02      = "Identificar el tono de un texto: triste, alegre, realista, etc."
       seb_03      = "Identificar los nexos que indiquen organizacin lgica"
       seb_04      = "Identificar el argumento de una crnica"
       seb_05      = "Interpretar el sentido irnico expresado en una crnica"
       seb_06      = "Identificar el tema central de una fbula"
       seb_07      = "Sustituir el tema central de la fbula por un refrn"
       seb_08      = "Identificar relaciones causa/efecto: fbula"
       seb_09      = "Interpretar las intenciones del personaje: fbula"
       seb_10      = "Identificar el tema global de una monografa"
       seb_11      = "Identificar la estructura de una monografa."
       seb_12      = "Interpretar el sentido metafrico de una frase"
       seb_13      = "Detectar el guin que organiza a una monografa"
       seb_14      = "Identificar el propsito de  una entrevista"
       seb_15      = "Identificar el gnero de un texto por su estructura: noticia"
       seb_16      = "Identificar concordancia gnero/nmero"
       seb_17      = "Determinar sujeto morfolgico: noticia"
       seb_18      = "Identificar el uso correcto de comillas"
       sec_01      = "Identificar a la noticia por su funcin"
       sec_02      = "Identificar la oracin temtica de una noticia"
       sec_03      = "Organizacin y secuencia de la noticia"
       sec_04      = "Reconocer expresiones connotativas: noticia"
       sec_05      = "Interpretar circunstancias como se dan los hechos: noticia"
       sec_06      = "Identificar el punto de vista del autor en un texto satrico"
       sec_07      = "Comprender el sentido real en un texto satrico"
       sec_08      = "Identificar el tono irnico en un texto satrico"
       sec_09      = "Identificar el uso correcto de sinnimos por el contexto"
       sec_10      = "Sintetizar la conclusin del autor en un artculo periodstico"
       sec_11      = "Identificar secuencia temporal: noticia"
       sec_12      = "Interpretar las circunstancias de cmo se dieron los hechos"
       sec_13      = "Interpretar la informacin que expresa el verbo (modo)"
       sec_14      = "Identificar la estructura correcta de una receta."
       sec_15      = "Identificar el uso de la coma en una receta"
       sec_16      = "Identificar errores ortogrficos de palabras con hie, hue, hum."
       sec_17      = "Identificar la funcin y uso del modo imperativo"
       sec_18      = "Identificar errores ortogrficos de palabras con ble, bilidad, bir, aba, vo, va"
       sec_19      = "Identificar el uso correcto de estar, parecer, lucir, quedar, llegar"
       sed_01      = "Comparar caractersticas de poesa tradicional/moderna"
       sed_02      = "Identificar caractersticas formales del poema tradicional"
       sed_03      = "Inferir el significado de una metfora: poema"
       sed_04      = "Inferir tono del poema"
       sed_05      = "Identificar el tema de un ensayo"
       sed_06      = "Reconocer el propsito general del ensayo"
       sed_07      = "Identificar la opinin del autor: ensayo"
       sed_08      = "Interpretar el desarrollo y la conclusin de un ensayo"
       sed_09      = "Identificar la sntesis de la conclusin en un ensayo"
       sed_10      = "Identificar argumentos persuasivos: ensayo"
       sed_11      = "Detectar la organizacin y secuencia de ideas: ensayo"
       sed_12      = "Identificar la parfrasis del tema central de un texto"
       sed_13      = "Detectar errores ortogrficos de palabras con gue, gui"
       sed_14      = "Identificar el propsito del autor: carta comercial"
       sed_15      = "Identificar las partes de la carta comercial"
       sed_16      = "Reconocer el uso correcto del acento grfico"
       sed_17      = "Identificar el uso correcto del acento diacrtico"
       sed_18      = "Identificar elementos de un vale"
       see_01      = "Distinguir el uso correcto de nexos subordinantes"
       see_02      = "Identificar una monografa por sus caractersticas"
       see_03      = "Interpretar la informacin de una grfica"
       see_04      = "Identificar la funcin de una oracin subordinada"
       see_05      = "Identificar nexos que introducen secuencias lgicas de ideas"
       see_06      = "Identificar el trmino anafrico y su sustitucin lxica"
       see_07      = "Identificar leyenda por su contenido y estructura"
       see_08      = "Identificar el tema central de una leyenda"
       see_09      = "Interpretar palabras indgenas de una leyenda"
       see_10      = "Inferir el sentido denotativo de una expresin: leyenda"
       see_11      = "Identificar el clmax de una leyenda"
       see_12      = "Identificar el espacio dnde ocurren los hechos: leyenda"
       see_13      = "Interpretar el tema de un fragmento de diario"
       see_14      = "Identificar el uso correcto de sinnimos"
       see_15      = "Reconocer el uso correcto de palabras homfonas"
       see_16      = "Identificar errores de concordancia verbal"
       see_17      = "Reconocer sinnimos de palabras utilizadas en un texto"
       see_18      = "Identificar guin de la entrevista"
       sef_01      = "Inferir el propsito del reportaje"
       sef_02      = "Interpretar relaciones causa/efecto: reportaje"
       sef_03      = "Inferir la conclusin: reportaje"
       sef_04      = "Determinar si el reportaje est prejuiciado o no"
       sef_05      = "Interpretar el significado de una palabra por contexto"
       sef_06      = "Identificar opinin de Sor Juana en uno de sus sonetos"
       sef_07      = "Interpretar el significado de una palabra por contexto"
       sef_08      = "Identificar la trama de un cuento clsico"
       sef_09      = "Identificar caractersticas psicolgicas de un personaje"
       sef_10      = "Interpretar relaciones causa/efecto en un cuento"
       sef_11      = "Identificar el ambiente en cuento clsico"
       sef_12      = "Identificar el uso correcto hacia, bajo, desde, sobre"
       sef_13      = "Identificar el uso errneo del participio"
       sef_14      = "Identificar el uso correcto de gerundios"
       sef_15      = "Identificar el pblico y lo que se publicita en un anuncio"
       sef_16      = "Identificar congruencia entre texto e ilustracin."
       sef_17      = "Identificar el uso correcto de signos ? e !"
       sef_18      = "Reconocer una funcin del infinitivo"
       seg_01      = "Identificar la funcin de un instructivo"
       seg_02      = "Identificar la estructura de un instructivo"
       seg_03      = "Identificar el orden lgico de instrucciones"
       seg_04      = "Interpretar el significado que aportan los signos ?"
       seg_05      = "Identificar el tema central de la crnica"
       seg_06      = "Identificar secuencia narrativa: crnica"
       seg_07      = "Identificar el lugar donde ocurren los hechos: crnica"
       seg_08      = "Identificar opinin del autor: noticia"
       seg_09      = "Identificar tipo de formatos: vale"
       seg_10      = "Identificar la noticia de otro gnero periodstico"
       seg_11      = "Interpretar los accidentes del  verbo"
       seg_12      = "Determinar funcin de oracin subordinada en contexto"
       seg_13      = "Comprender significado de un sustantivo en contexto"
       seg_14      = "Completar informacin en un cuadro sinptico"
       seg_15      = "Identificar oracin subordinada"
       seg_16      = "Identificar funcin de oracin subordinada"
       seg_17      = "Identificar el uso correcto de enlaces subordinantes"
       seg_18      = "Detectar errores ortogrficos en palabras con ger, gir"
       seh_01      = "Identificar el tema de un artculo de divulgacin"
       seh_02      = "Elegir un ttulo relevante para un artculo de divulgacin"
       seh_03      = "Identificar la idea principal de un prrafo: artculo divulgacin"
       seh_04      = "Identificar sinnimos: artculo de divulgacin"
       seh_05      = "Evaluar crticamente la organizacin de un artculo de divulgacin"
       seh_06      = "Elegir el gnero del texto: cuento"
       seh_07      = "Identificar el tema de un cuento"
       seh_08      = "Identificar la conclusin de un cuento expresada en parfrasis"
       seh_09      = "Seleccionar el contexto sociocultural del cuento"
       seh_10      = "Identificar intenciones de un personaje"
       seh_11      = "Inferir  relaciones causa/efecto en un cuento"
       seh_12      = "Identificar secuencia temporal: cuento"
       seh_13      = "Identificar el refrn que puede sustituir el tema de un cuento"
       seh_14      = "Identificar congruencia entre accin y caractersticas de un personaje"
       seh_15      = "Identificar intenciones del autor: ancdota"
       seh_16      = "Identificar el significado de una palabra homfona"
       seh_17      = "Identificar puntuacin correcta en oraciones yuxtapuestas"
       seh_18      = "Identificar uso correcto de conjunciones en oraciones coordinadas"
       pv1esp      = "Primer valor plausible de Espaol"
       pv2esp      = "Segundo valor plausible de Espaol"
       pv3esp      = "Tercer valor plausible de Espaol"
       pv4esp      = "Cuarto valor plausible de Espaol"
       pv5esp      = "Quinto valor plausible de Espaol"
       espnvl1     = "Nivel de logro en Espaol. Asociado a PV1ESP. (Cuatro niveles)"
       espnvl2     = "Nivel de logro en Espaol. Asociado a PV2ESP. (Cuatro niveles)"
       espnvl3     = "Nivel de logro en Espaol. Asociado a PV3ESP. (Cuatro niveles)"
       espnvl4     = "Nivel de logro en Espaol. Asociado a PV4ESP. (Cuatro niveles)"
       espnvl5     = "Nivel de logro en Espaol. Asociado a PV5ESP. (Cuatro niveles)"
       espnvlb1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV1ESP."
       espnvlb2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV2ESP."
       espnvlb3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV3ESP."
       espnvlb4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV4ESP."
       espnvlb5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV5ESP."
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       mageb05            mageb05F.
       estrato            $char7.
       entest             $char6.
       alumno             5.
       id_instr           $char16.
       sexo               sexoF.
       edad               edadF.
       edadc              edadcF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       sea_01             ea1_h18F.
       sea_02             ea1_h18F.
       sea_03             ea1_h18F.
       sea_04             ea1_h18F.
       sea_05             ea1_h18F.
       sea_06             ea1_h18F.
       sea_07             ea1_h18F.
       sea_08             ea1_h18F.
       sea_09             ea1_h18F.
       sea_10             ea1_h18F.
       sea_11             ea1_h18F.
       sea_12             ea1_h18F.
       sea_13             ea1_h18F.
       sea_14             ea1_h18F.
       sea_15             ea1_h18F.
       sea_16             ea1_h18F.
       sea_17             ea1_h18F.
       sea_18             ea1_h18F.
       seb_01             ea1_h18F.
       seb_02             ea1_h18F.
       seb_03             ea1_h18F.
       seb_04             ea1_h18F.
       seb_05             ea1_h18F.
       seb_06             ea1_h18F.
       seb_07             ea1_h18F.
       seb_08             ea1_h18F.
       seb_09             ea1_h18F.
       seb_10             ea1_h18F.
       seb_11             ea1_h18F.
       seb_12             ea1_h18F.
       seb_13             ea1_h18F.
       seb_14             ea1_h18F.
       seb_15             ea1_h18F.
       seb_16             ea1_h18F.
       seb_17             ea1_h18F.
       seb_18             ea1_h18F.
       sec_01             ea1_h18F.
       sec_02             ea1_h18F.
       sec_03             ea1_h18F.
       sec_04             ea1_h18F.
       sec_05             ea1_h18F.
       sec_06             ea1_h18F.
       sec_07             ea1_h18F.
       sec_08             ea1_h18F.
       sec_09             ea1_h18F.
       sec_10             ea1_h18F.
       sec_11             ea1_h18F.
       sec_12             ea1_h18F.
       sec_13             ea1_h18F.
       sec_14             ea1_h18F.
       sec_15             ea1_h18F.
       sec_16             ea1_h18F.
       sec_17             ea1_h18F.
       sec_18             ea1_h18F.
       sec_19             ea1_h18F.
       sed_01             ea1_h18F.
       sed_02             ea1_h18F.
       sed_03             ea1_h18F.
       sed_04             ea1_h18F.
       sed_05             ea1_h18F.
       sed_06             ea1_h18F.
       sed_07             ea1_h18F.
       sed_08             ea1_h18F.
       sed_09             ea1_h18F.
       sed_10             ea1_h18F.
       sed_11             ea1_h18F.
       sed_12             ea1_h18F.
       sed_13             ea1_h18F.
       sed_14             ea1_h18F.
       sed_15             ea1_h18F.
       sed_16             ea1_h18F.
       sed_17             ea1_h18F.
       sed_18             ea1_h18F.
       see_01             ea1_h18F.
       see_02             ea1_h18F.
       see_03             ea1_h18F.
       see_04             ea1_h18F.
       see_05             ea1_h18F.
       see_06             ea1_h18F.
       see_07             ea1_h18F.
       see_08             ea1_h18F.
       see_09             ea1_h18F.
       see_10             ea1_h18F.
       see_11             ea1_h18F.
       see_12             ea1_h18F.
       see_13             ea1_h18F.
       see_14             ea1_h18F.
       see_15             ea1_h18F.
       see_16             ea1_h18F.
       see_17             ea1_h18F.
       see_18             ea1_h18F.
       sef_01             ea1_h18F.
       sef_02             ea1_h18F.
       sef_03             ea1_h18F.
       sef_04             ea1_h18F.
       sef_05             ea1_h18F.
       sef_06             ea1_h18F.
       sef_07             ea1_h18F.
       sef_08             ea1_h18F.
       sef_09             ea1_h18F.
       sef_10             ea1_h18F.
       sef_11             ea1_h18F.
       sef_12             ea1_h18F.
       sef_13             ea1_h18F.
       sef_14             ea1_h18F.
       sef_15             ea1_h18F.
       sef_16             ea1_h18F.
       sef_17             ea1_h18F.
       sef_18             ea1_h18F.
       seg_01             ea1_h18F.
       seg_02             ea1_h18F.
       seg_03             ea1_h18F.
       seg_04             ea1_h18F.
       seg_05             ea1_h18F.
       seg_06             ea1_h18F.
       seg_07             ea1_h18F.
       seg_08             ea1_h18F.
       seg_09             ea1_h18F.
       seg_10             ea1_h18F.
       seg_11             ea1_h18F.
       seg_12             ea1_h18F.
       seg_13             ea1_h18F.
       seg_14             ea1_h18F.
       seg_15             ea1_h18F.
       seg_16             ea1_h18F.
       seg_17             ea1_h18F.
       seg_18             ea1_h18F.
       seh_01             ea1_h18F.
       seh_02             ea1_h18F.
       seh_03             ea1_h18F.
       seh_04             ea1_h18F.
       seh_05             ea1_h18F.
       seh_06             ea1_h18F.
       seh_07             ea1_h18F.
       seh_08             ea1_h18F.
       seh_09             ea1_h18F.
       seh_10             ea1_h18F.
       seh_11             ea1_h18F.
       seh_12             ea1_h18F.
       seh_13             ea1_h18F.
       seh_14             ea1_h18F.
       seh_15             ea1_h18F.
       seh_16             ea1_h18F.
       seh_17             ea1_h18F.
       seh_18             ea1_h18F.
       wvarstrr           2.
 ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(145)
                   sea_01 sea_02 sea_03 sea_04 sea_05 sea_06 sea_07 sea_08 sea_09 sea_10
                   sea_11 sea_12 sea_13 sea_14 sea_15 sea_16 sea_17 sea_18 seb_01 seb_02
                   seb_03 seb_04 seb_05 seb_06 seb_07 seb_08 seb_09 seb_10 seb_11 seb_12
                   seb_13 seb_14 seb_15 seb_16 seb_17 seb_18 sec_01 sec_02 sec_03 sec_04
                   sec_05 sec_06 sec_07 sec_08 sec_09 sec_10 sec_11 sec_12 sec_13 sec_14
                   sec_15 sec_16 sec_17 sec_18 sec_19 sed_01 sed_02 sed_03 sed_04 sed_05
                   sed_06 sed_07 sed_08 sed_09 sed_10 sed_11 sed_12 sed_13 sed_14 sed_15
                   sed_16 sed_17 sed_18 see_01 see_02 see_03 see_04 see_05 see_06 see_07
                   see_08 see_09 see_10 see_11 see_12 see_13 see_14 see_15 see_16 see_17
                   see_18 sef_01 sef_02 sef_03 sef_04 sef_05 sef_06 sef_07 sef_08 sef_09
                   sef_10 sef_11 sef_12 sef_13 sef_14 sef_15 sef_16 sef_17 sef_18 seg_01
                   seg_02 seg_03 seg_04 seg_05 seg_06 seg_07 seg_08 seg_09 seg_10 seg_11
                   seg_12 seg_13 seg_14 seg_15 seg_16 seg_17 seg_18 seh_01 seh_02 seh_03
                   seh_04 seh_05 seh_06 seh_07 seh_08 seh_09 seh_10 seh_11 seh_12 seh_13
                   seh_14 seh_15 seh_16 seh_17 seh_18;
   DO  i=1 TO 145;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
